@@ -1,5 +1,5 @@
 #encoding: utf-8
-from .common import ProgressBarBase
+from .base import ProgressBarBase
 import sys
 
 
@@ -13,17 +13,25 @@ class ProgressBarTerminal(ProgressBarBase):
         super(ProgressBarTerminal, self).__init__(iterable_or_max, title, key, autohide, quiet)
         self.format_strs = format_str.split('%(bar)s')
         self.width = width
-        self.phases = (u' ', u'▏', u'▎', u'▍', u'▌', u'▋', u'▊', u'▉', u'█')
+        self.quiet = quiet
+        self.phases = (' ', '▏', '▎', '▍', '▌', '▋', '▊', '▉', '█')
+
+    def p(self, s=None):
+        if not self.quiet:
+            if s is None:
+                print()
+            else:
+                print(s, end=' ')
 
     def print_output(self):
         parts = [format % self for format in self.format_strs]
         parts[1:1] = self.bar(self.width - sum(map(len, parts)))
-        print '\r' + ''.join(parts),
+        self.p( '\r' + ''.join(parts))
         sys.stdout.flush()
 
     def start(self):
         super(ProgressBarTerminal, self).start()
-        print
+        self.p()
         self.print_output()
 
     def advance(self):
@@ -33,21 +41,20 @@ class ProgressBarTerminal(ProgressBarBase):
     def finish(self):
         super(ProgressBarTerminal, self).finish()
         if not self.autohide:
-            print
+            self.p()
 
     def hide(self):
         super(ProgressBarTerminal, self).hide()
-        print (' ' * self.width) + '\r',
+        self.p((' ' * self.width) + '\r')
         sys.stdout.flush()
 
     def bar(self, bar_width):
-        completely_filled = self.current * bar_width / self.max
-        phase = (self.current * bar_width * len(self.phases) / self.max) % len(self.phases)
+        completely_filled = self.current * bar_width // self.max
+        phase = (self.current * bar_width * len(self.phases) // self.max) % len(self.phases)
 
         return (self.phases[-1] * completely_filled +
                 (self.phases[phase] if completely_filled < bar_width else '') +
                 self.phases[0] * (bar_width - completely_filled))
 
     def set_extra_text(self, text):
-        super(ProgressBarTerminal, self).set_extra_text()
-        raise NotImplementedError
+        super(ProgressBarTerminal, self).set_extra_text(text)
